P300 Speller — BCI-Framework documentation

# P300 Speller

class `bci_framework.default_extensions.P300_Speller.main.` `P300Speller`

  Classic P300 speller.

  `activate`(array: List[str], target: str) → None

    Highlight a column or a row.

  `build_grid`() → None

    Create the grid with the letters.

  `build_trials`() → None

    Define the trials and pipeline trials.

    The trials consist (in this case) in a list of cues. The pipeline trials is a set of couples (callable, duration) that define a single trial, this list of functions are executed asynchronously and repeated for each trial.

  `inter_stimulus`() → None

    Remove the highlight over the focus character.

  `start`() → None

    Start the run.

    A run consist in a consecutive pipeline trials execution.

  `stop`() → None

    Stop pipeline execution.

  `synchronizer`(value: bool) → None

    Show or hide synchronizer.

  `target_notice`(target: str) → None

    Highlight the character that’s subject must focus on.